--- modules/system/system.api.php	2010-01-10 10:03:21.000000000 +1100
+++ modules/system/system.api.php	2010-01-12 22:06:48.000000000 +1100
@@ -31,9 +31,9 @@
  *     system will determine whether a file with the name $module.$group.inc
  *     exists, and automatically load it when required.
  *
  * See system_hook_info() for all hook groups defined by Drupal core.
  */
-function hook_hook_info() {
+function hook_define_hooks() {
   $hooks['token_info'] = array(
     'group' => 'tokens',
   );
@@ -31,9 +31,9 @@
  *     exists, and automatically load it when required.
  *
- * See system_hook_info() for all hook groups defined by Drupal core.
+ * See system_define_hooks() for all hook groups defined by Drupal core.
  */
